EXPORTS
	??0TAccPolGenericIDAccessor@@AAE@XZ @ 1 NONAME ; TAccPolGenericIDAccessor::TAccPolGenericIDAccessor(void)
	??1CAccPolAccessoryPolicy@@UAE@XZ @ 2 NONAME ; CAccPolAccessoryPolicy::~CAccPolAccessoryPolicy(void)
	??1CCapabilityStorage@@UAE@XZ @ 3 NONAME ; CCapabilityStorage::~CCapabilityStorage(void)
	?AppendNameL@TAccPolSubblockNameArrayAccessor@@SAXAAVCAccPolSubblockNameArray@@ABK@Z @ 4 NONAME ; void TAccPolSubblockNameArrayAccessor::AppendNameL(class CAccPolSubblockNameArray &, unsigned long const &)
	?Array@TAccPolSubblockNameArrayAccessor@@SAPAV?$RArray@K@@PAVCAccPolSubblockNameArray@@@Z @ 5 NONAME ; class RArray<unsigned long> * TAccPolSubblockNameArrayAccessor::Array(class CAccPolSubblockNameArray *)
	?CapabilityInUse@CCapabilityStorage@@QAEHABVTAccPolGenericID@@ABK@Z @ 6 NONAME ; int CCapabilityStorage::CapabilityInUse(class TAccPolGenericID const &, unsigned long const &)
	?CompareGenericID@TAccPolGenericIDAccessor@@SAHABVTAccPolGenericID@@0@Z @ 7 NONAME ; int TAccPolGenericIDAccessor::CompareGenericID(class TAccPolGenericID const &, class TAccPolGenericID const &)
	?CopyGenericIDArray@TAccPolGenericIDArrayAccessor@@SAXABVTAccPolGenericIDArray@@AAV2@@Z @ 8 NONAME ; void TAccPolGenericIDArrayAccessor::CopyGenericIDArray(class TAccPolGenericIDArray const &, class TAccPolGenericIDArray &)
	?DebugPrint@TAccPolGenericIDAccessor@@SAXABVTAccPolGenericID@@@Z @ 9 NONAME ; void TAccPolGenericIDAccessor::DebugPrint(class TAccPolGenericID const &)
	?EvaluateConnectionRulesL@CAccPolAccessoryPolicy@@QAEXABVTAccPolGenericID@@AAK@Z @ 10 NONAME ; void CAccPolAccessoryPolicy::EvaluateConnectionRulesL(class TAccPolGenericID const &, unsigned long &)
	?ExternalizeCapabilityNameListL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@AAVRBufWriteStream@@@Z @ 11 NONAME ; void CCapabilityStorage::ExternalizeCapabilityNameListL(class TAccPolGenericID const &, class RBufWriteStream &)
	?ExternalizeL@TAccPolCapsSubblockNameArraySerial@@SAXABVCAccPolSubblockNameArray@@AAVRWriteStream@@@Z @ 12 NONAME ; void TAccPolCapsSubblockNameArraySerial::ExternalizeL(class CAccPolSubblockNameArray const &, class RWriteStream &)
	?ExternalizeL@TAccPolNameValueArraySerial@@SAXABV?$RArray@VTAccPolNameValueRecord@@@@AAVRWriteStream@@@Z @ 13 NONAME ; void TAccPolNameValueArraySerial::ExternalizeL(class RArray<class TAccPolNameValueRecord> const &, class RWriteStream &)
	?FindWithDeviceAddressL@TAccPolGenericIDArrayAccessor@@SAHABVTAccPolGenericIDArray@@AB_K@Z @ 14 NONAME ; int TAccPolGenericIDArrayAccessor::FindWithDeviceAddressL(class TAccPolGenericIDArray const &, unsigned long long const &)
	?FindWithHWDeviceIDL@TAccPolGenericIDArrayAccessor@@SAHABVTAccPolGenericIDArray@@AB_K@Z @ 15 NONAME ; int TAccPolGenericIDArrayAccessor::FindWithHWDeviceIDL(class TAccPolGenericIDArray const &, unsigned long long const &)
	?FindWithUniqueIDL@TAccPolGenericIDArrayAccessor@@SAHABVTAccPolGenericIDArray@@H@Z @ 16 NONAME ; int TAccPolGenericIDArrayAccessor::FindWithUniqueIDL(class TAccPolGenericIDArray const &, int)
	?GenerateUniqueId@CCapabilityStorage@@QAEXAAVTAccPolGenericID@@@Z @ 17 NONAME ; void CCapabilityStorage::GenerateUniqueId(class TAccPolGenericID &)
	?GenericIDRef@TAccPolGenericIDAccessor@@SAAAVTAccPolGenericID@@PAVCAccConGenericID@@@Z @ 18 NONAME ; class TAccPolGenericID & TAccPolGenericIDAccessor::GenericIDRef(class CAccConGenericID *)
	?GetAllCriticalCapabilitiesL@CAccPolAccessoryPolicy@@QBEXXZ @ 19 NONAME ; void CAccPolAccessoryPolicy::GetAllCriticalCapabilitiesL(void) const
	?GetCapability@CCapabilityStorage@@QAEPAVCCapValue@@ABVTAccPolGenericID@@ABK@Z @ 20 NONAME ; class CCapValue * CCapabilityStorage::GetCapability(class TAccPolGenericID const &, unsigned long const &)
	?GetCount@TAccPolSubblockNameArrayAccessor@@SAHABVCAccPolSubblockNameArray@@@Z @ 21 NONAME ; int TAccPolSubblockNameArrayAccessor::GetCount(class CAccPolSubblockNameArray const &)
	?GetGenericID@CCapabilityStorage@@QAEXAAVTAccPolGenericID@@@Z @ 22 NONAME ABSENT ; void CCapabilityStorage::GetGenericID(class TAccPolGenericID &)
	?GetName@TAccPolSubblockNameArrayAccessor@@SAXABVCAccPolSubblockNameArray@@HAAK@Z @ 23 NONAME ; void TAccPolSubblockNameArrayAccessor::GetName(class CAccPolSubblockNameArray const &, int, unsigned long &)
	?InternalizeL@TAccPolCapsSubblockNameArraySerial@@SAXAAVRReadStream@@AAVCAccPolSubblockNameArray@@@Z @ 24 NONAME ; void TAccPolCapsSubblockNameArraySerial::InternalizeL(class RReadStream &, class CAccPolSubblockNameArray &)
	?InternalizeToArrayL@CCapabilityStorage@@AAEXAAVRReadStream@@AAV?$RPointerArray@VCCapValue@@@@@Z @ 25 NONAME ; void CCapabilityStorage::InternalizeToArrayL(class RReadStream &, class RPointerArray<class CCapValue> &)
	?IsValidConnectionL@CAccPolAccessoryPolicy@@QAE?AW4TAccSrvConnection@@ABVTAccPolGenericID@@AAH@Z @ 26 NONAME ; enum TAccSrvConnection CAccPolAccessoryPolicy::IsValidConnectionL(class TAccPolGenericID const &, int &)
	?Location@CCapValue@@QBE?AW4TAccPolValueLocation@@XZ @ 27 NONAME ; enum TAccPolValueLocation CCapValue::Location(void) const
	?Name@CCapValue@@QBEKXZ @ 28 NONAME ; unsigned long CCapValue::Name(void) const
	?NameValueBuf@TAccPolGenericIDAccessor@@SAPAVCBufFlat@@PAVCAccConGenericID@@@Z @ 29 NONAME ; class CBufFlat * TAccPolGenericIDAccessor::NameValueBuf(class CAccConGenericID *)
	?NewCapabilityListL@CCapabilityStorage@@QAEHABVTAccPolGenericID@@AAVRBufReadStream@@@Z @ 30 NONAME ; int CCapabilityStorage::NewCapabilityListL(class TAccPolGenericID const &, class RBufReadStream &)
	?NewCapabilityListL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@@Z @ 31 NONAME ; void CCapabilityStorage::NewCapabilityListL(class TAccPolGenericID const &)
	?NewL@CAccPolAccessoryPolicy@@SAPAV1@PAVCCapabilityStorage@@@Z @ 32 NONAME ; class CAccPolAccessoryPolicy * CAccPolAccessoryPolicy::NewL(class CCapabilityStorage *)
	?NewL@CCapabilityStorage@@SAPAV1@XZ @ 33 NONAME ; class CCapabilityStorage * CCapabilityStorage::NewL(void)
	?ParseGenericIDContentL@CAccPolAccessoryPolicy@@QAEXPAVCAccConGenericID@@_KABVTDesC16@@ABVTDes8@@W4TAccGIDtype@@@Z @ 34 NONAME ; void CAccPolAccessoryPolicy::ParseGenericIDContentL(class CAccConGenericID *, unsigned long long, class TDesC16 const &, class TDes8 const &, enum TAccGIDtype)
	?RemoveCapabilityList@CCapabilityStorage@@QAEHABVTAccPolGenericID@@@Z @ 35 NONAME ; int CCapabilityStorage::RemoveCapabilityList(class TAccPolGenericID const &)
	?ReplaceArrayL@TAccPolGenericIDArrayAccessor@@SAXAAVTAccPolGenericIDArray@@ABV?$RArray@VTAccPolGenericID@@@@@Z @ 36 NONAME ; void TAccPolGenericIDArrayAccessor::ReplaceArrayL(class TAccPolGenericIDArray &, class RArray<class TAccPolGenericID> const &)
	?ResetArray@TAccPolSubblockNameArrayAccessor@@SAXAAVCAccPolSubblockNameArray@@@Z @ 37 NONAME ; void TAccPolSubblockNameArrayAccessor::ResetArray(class CAccPolSubblockNameArray &)
	?ResolveAccessoryModeL@CAccPolAccessoryPolicy@@QAE?AUTAccPolAccessoryMode@@ABVTAccPolGenericIDArray@@HHU2@H@Z @ 38 NONAME ; struct TAccPolAccessoryMode CAccPolAccessoryPolicy::ResolveAccessoryModeL(class TAccPolGenericIDArray const &, int, int, struct TAccPolAccessoryMode, int)
	?ResolveCriticalCapabilitiesL@CAccPolAccessoryPolicy@@QAEXABVTAccPolGenericID@@AAVCAccPolSubblockNameArray@@@Z @ 39 NONAME ; void CAccPolAccessoryPolicy::ResolveCriticalCapabilitiesL(class TAccPolGenericID const &, class CAccPolSubblockNameArray &)
	?ResolveCriticalCapabilitiesL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@AAVCAccPolSubblockNameArray@@@Z @ 40 NONAME ; void CCapabilityStorage::ResolveCriticalCapabilitiesL(class TAccPolGenericID const &, class CAccPolSubblockNameArray &)
	?SetCapabilityL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@ABK@Z @ 41 NONAME ; void CCapabilityStorage::SetCapabilityL(class TAccPolGenericID const &, unsigned long const &)
	?SetCapabilityL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@ABKABW4TAccPolValueLocation@@ABW4TAccPolValueType@@ABJ@Z @ 42 NONAME ; void CCapabilityStorage::SetCapabilityL(class TAccPolGenericID const &, unsigned long const &, enum TAccPolValueLocation const &, enum TAccPolValueType const &, long const &)
	?SetCriticalCapabilityL@CCapabilityStorage@@QAEXABKABW4TAccPolValueLocation@@ABW4TAccPolValueType@@ABJ@Z @ 43 NONAME ; void CCapabilityStorage::SetCriticalCapabilityL(unsigned long const &, enum TAccPolValueLocation const &, enum TAccPolValueType const &, long const &)
	?SetDBID@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@H@Z @ 44 NONAME ; void TAccPolGenericIDAccessor::SetDBID(class TAccPolGenericID &, int)
	?SetDeviceAddress@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@_K@Z @ 45 NONAME ; void TAccPolGenericIDAccessor::SetDeviceAddress(class TAccPolGenericID &, unsigned long long)
	?SetFeatureAttributeL@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@IK@Z @ 46 NONAME ; void TAccPolGenericIDAccessor::SetFeatureAttributeL(class TAccPolGenericID &, unsigned int, unsigned long)
	?SetFeatureAttributeL@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@I_K@Z @ 47 NONAME ; void TAccPolGenericIDAccessor::SetFeatureAttributeL(class TAccPolGenericID &, unsigned int, unsigned long long)
	?SetGenericIDHeaderL@CCapabilityStorage@@QAEXABUTAccPolGIDHeader@@@Z @ 48 NONAME ; void CCapabilityStorage::SetGenericIDHeaderL(struct TAccPolGIDHeader const &)
	?SetGenericIDStaticAttributes@TAccPolGenericIDAccessor@@SAXPAVCAccConGenericID@@ABVTAccPolGenericID@@@Z @ 49 NONAME ; void TAccPolGenericIDAccessor::SetGenericIDStaticAttributes(class CAccConGenericID *, class TAccPolGenericID const &)
	?SetHWDeviceID@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@_K@Z @ 50 NONAME ; void TAccPolGenericIDAccessor::SetHWDeviceID(class TAccPolGenericID &, unsigned long long)
	?SetHWModelID@TAccPolGenericIDAccessor@@SAXAAVTAccPolGenericID@@ABVTDesC16@@@Z @ 51 NONAME ; void TAccPolGenericIDAccessor::SetHWModelID(class TAccPolGenericID &, class TDesC16 const &)
	?SetValueL@CCapValue@@QAEXABJ@Z @ 52 NONAME ; void CCapValue::SetValueL(long const &)
	?SetValueL@CCapValue@@QAEXABVTDesC8@@@Z @ 53 NONAME ; void CCapValue::SetValueL(class TDesC8 const &)
	?SupportedHWDevicesL@CAccPolAccessoryPolicy@@QAEKXZ @ 54 NONAME ; unsigned long CAccPolAccessoryPolicy::SupportedHWDevicesL(void)
	?Type@CCapValue@@QBE?AW4TAccPolValueType@@XZ @ 55 NONAME ; enum TAccPolValueType CCapValue::Type(void) const
	?UpdateGenericIDL@CAccPolAccessoryPolicy@@QAEXAAVTAccPolGenericID@@ABH@Z @ 56 NONAME ; void CAccPolAccessoryPolicy::UpdateGenericIDL(class TAccPolGenericID &, int const &)
	?UseUpdatedGenericIDL@CCapabilityStorage@@QAEXABVTAccPolGenericID@@@Z @ 57 NONAME ; void CCapabilityStorage::UseUpdatedGenericIDL(class TAccPolGenericID const &)
	?ValueDesc@CCapValue@@QBEHAAVTPtrC8@@@Z @ 58 NONAME ; int CCapValue::ValueDesc(class TPtrC8 &) const
	?ValueInt@CCapValue@@QBEHAAJ@Z @ 59 NONAME ; int CCapValue::ValueInt(long &) const
	?CompareCriticalValuesL@CCapabilityStorage@@QAEHABVTAccPolGenericID@@@Z @ 60 NONAME ; int CCapabilityStorage::CompareCriticalValuesL(class TAccPolGenericID const &)
	?GetGenericID@CCapabilityStorage@@QAEHAAVTAccPolGenericID@@@Z @ 61 NONAME ; int CCapabilityStorage::GetGenericID(class TAccPolGenericID &)

